// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//----------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                    (c) 1997-2010, European Space Agency
//
//---------------------------------------------------------------------------
//
//	ColumnGenerator.h:	--- an abstract interface to generate new columns
//
//	DESCRIPTION:
//		A class ColumnGenerator is defined which acts as an abstract interface
//		to create new columns in a table
//
//	CHANGE HISTORY:
//		UL, 1999-04-27: 1.0.0: - first version
//
//	AUTHOR:
//		U. Lammers (UL), Wed Aug 27 11:48:12 MET DST 1997
//
//	$Header: /sasbuild/repositories/sasdev/sas/packages/selectlib/src/service/ColumnGenerator.h,v 1.3 2002/07/09 14:06:31 ulammers Exp $
//

#ifndef COLUMN_GENERATOR_H
#define COLUMN_GENERATOR_H

#include <string>
#include "Evaluator.h"
#if !defined(NON_SAS)
	#include "Dal.h"
#endif

class ColumnGenerator {
public:
	ColumnGenerator(const std::string &columnName = "TEMP",
					Dal::DataType dataType = Dal::Real64)
		: _columnName(columnName), _dataType(dataType) {}

		//
		//	PURPOSE:
		//		Create a ColumnGenerator object
		//
		//	ARGUMENTS:
		//		In:
		//			columnName: the name of the new column to construct
		//			dataType  : the type of the new column to construct


	std::string columnName() const { return _columnName; }
	void setColumnName(const std::string &newColumnName)
		{ _columnName = newColumnName; }
	Dal::DataType dataType() const { return _dataType; }
	void setDataType(Dal::DataType newDataType) { _dataType = newDataType; }
		//
		//	PURPOSE:
		//		Return name/type of the column which this object constructs
		//		or set new values


	virtual void doIt(const Table &inTable, Table &outTable) const = 0;
		//
		//	PURPOSE:
		//		Create a new column in a table potentially using data
		//		from other columns in another table
		//
		//	ARGUMENTS:
		//		In:
		//			inTable:	the table containing the columns the
		//						construction of the new column should
		//						use
		//
		//		InOut:
		//			outTable:	the table to which the newly created column
		//						<colName> will be added; <outTable> and
		//						<inTable> can be identical.

	virtual ~ColumnGenerator() {}
 		//
		//	PURPOSE:
		//		destroy the object constructed with either of the above
		//		constructors

private:
	std::string		_columnName;
	Dal::DataType	_dataType;
};

#endif
