// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//----------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                    (c) 1997-2010 European Space Agency
//
//---------------------------------------------------------------------------
//
//	ServiceUtils.h:	--- utilities for selector services
//
//	DESCRIPTION:
//		A collection of utilities for the selector services
//
//	CHANGE HISTORY:
//		UL, 1998-05-19: 1.0.0: - first version
//		UL, 1999-05-12: 1.1.0: - added method: attributeFreeExpression()
//		UL, 1999-10-08: 1.1.1: - added optional argument to attribute free
//								 expression which signifies a list of attribute
//								 names that should not be replaced
//		UL, 2000-07-03: 1.2.0: - several changes related to support of string
//								 columns
//
//	AUTHOR:
//		U. Lammers (UL), Wed Aug 27 11:48:12 MET DST 1997
//
//	$Header: /sasbuild/repositories/sasdev/sas/packages/selectlib/src/service/ServiceUtils.h,v 1.2 2001/08/10 16:14:59 ulammers Exp $
//

#ifndef SERVICE_UTILS_H
#define SERVICE_UTILS_H

#include <string>
#include <vector>

#include "Evaluator.h"
#include "Dal.h"

class ServiceUtils {
public:
	typedef double (*ConvFuncPtr)(void *, unsigned long);

	static std::vector<ColumnData *>
			prepareEvaluation(const Evaluator *evaluator,
							  const Table &table,
							  double **&valPtr,
							  unsigned &nNumericIds, void **&dataVec,
							  ConvFuncPtr *&convFuncVec,
							  char **&textValPtr,
							  unsigned &nTextIds, char **&textDataVec,
							  unsigned *&textFieldLength);
	//
	//	PURPOSE:
	//		assign attribute value, figure list of identifiers
	//


	static std::string attributeFreeExpression(const std::string &expression,
										  const Table *table,
										  const std::vector<std::string>
													*specialAttributes = 0);
	//
	//	PURPOSE:
	//		replace in a given selection expression all references to table
	//		attributes by the actual attribute values; this works
	//		recursively, i.e., subexpressions in attributes can contain
	//		references to other attributes
	//
	//	ARGUMENTS:
	//		expression			: selection expression
	//		table				: table containing attributes
	//		specialAttributes	: optional list of special attributes which
	//							  should not be replaced
	//

};

#endif
