// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//---------------------------------------------------------------------------
//
//                     XMM Science Analysis System (SAS)
//                    (c) 1997-2010 European Space Agency
//
//---------------------------------------------------------------------------
//
//	SelectError.cc: --- error handling
//
//	DESCRIPTION:
//
//	CHANGE HISTORY:
//		UL, 1998-05-15: 1.0.0: - first version
//		UL, 1999-10-13: 2.0.0: - overhauled: added exception handling
//		UL, 1999-12-14: 2.0.1: - closed minor memory leak
//		UL, 2000-02-03: 2.1.0: - commented all 'delete p;' statements below
//								 because they cause a seg-fault
//								 (this fixed second part of SPR 1101: behavior
//								 with empty GTI tables); need to check again
//
//	AUTHOR:
//		U. Lammers (UL), Fri May 15 09:37:22 MET DST 1998
//
//	$Header: /sasbuild/repositories/sasdev/sas/packages/selectlib/src/utils/SelectError.cc,v 1.2 2002/06/28 15:55:31 ulammers Exp $
//

#include "SelectError.h"

//
//	instantiate single SelectErrorHandler object
//
namespace SelectError {

SelectErrorHandler	selectErrorHandler(false);	//	no exceptions by default

}

#if !defined(NON_SAS)
#include "errstr.h"
#endif

namespace SelectError {
#if !defined(NON_SAS)

SelectErrorHandler::Flush SelectErrorHandler::error(
											const std::string &errorTag, int)
{
	_text = errorstream.str();
	//	empty errorstream
	errorstream.seekp(0);

	if (!_exceptions)
		errstr<<_text<<Sas::error(errorTag);
	else
		_text = "Error: " + errorTag + ": " + _text;

	return SelectErrorHandler::FLUSH;
} // SelectErrorHandler::error()


SelectErrorHandler::Flush SelectErrorHandler::warning(
													const std::string &warnTag)
{
	_text = errorstream.str();
	//	empty errorstream
	errorstream.seekp(0);

	errstr<<_text<<Sas::warning(warnTag);

	return SelectErrorHandler::FLUSH;
} // SelectErrorHandler::warning()


#else

//
//	outside the SAS environment we print to `cerr' and bail out with
//	exit()
//
#include <cstdlib>	//	exit()

SelectErrorHandler::Flush SelectErrorHandler::error(
								const std::string &errorTag, int errorCode)
{
	_text = errorstream.str();
	_text = p;
	//	empty errorstream
	errorstream.seekp(0);

	_text = "Error: " + errorTag + ": " + _text;
	if (!_exceptions) {
		cerr<<_text<<endl;
		exit(errorCode);
	}

	return SelectErrorHandler::FLUSH;
} // SelectErrorHandler::error()


SelectErrorHandler::Flush SelectErrorHandler::warning(
													const std::string &warnTag)
{
	_text = errorstream.str();
	//	empty errorstream
	errorstream.seekp(0);

	_text = "Warning: " + warnTag + ": " + _text;	
	cerr<<_text<<endl;

	return SelectErrorHandler::FLUSH;
} // SelectErrorHandler::warning()

#endif

} // namespace SelectError
