// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
//
//	test GeoRegion class
//
#include <iostream>

#include "Region.h"
#include "common.h"

int main() {
	const double L = 1.,
				 R = .2;
	const unsigned N = 300;

	//	construct modified Venn diagramm: two included overlapping circles;
	//	core excised and another excluded circle
	Component cinc;
	cinc.push_back(new FCircle(FPoint(.5*L-.9*R, .5*L+.9*R), R));
	cinc.push_back(new FCircle(FPoint(.5*L+.9*R, .5*L+.9*R), R));

	Component cexc;
	cexc.push_back(new FCircle(FPoint(.5*L, .5*L+.9*R), .2*R));
	cexc.push_back(new FCircle(FPoint(.5*L, .5*L-.7*R), R));
	cexc.exclude();

	GeoRegion r;
	r.push_back(cinc);
	r.push_back(cexc);

	std::cerr<<r.toSelectExpression("X", "Y")<<std::endl;
	for (unsigned xi=0; xi<N; ++xi)
		for (unsigned yi=0; yi<N; ++yi) {
			double x = L/DBL(N)*DBL(xi),
				   y = L/DBL(N)*DBL(yi);
			if (r.contains(FPoint(x, y)))
				std::cout<<x<<' '<<y<<std::endl;
		}
}
